# torchmd-cg

## Installation

```
conda create -n torchmd_cg
conda activate torchmd_cg
conda install pytorch torchvision cudatoolkit=10.1 -c pytorch
conda install pyyaml ipython scikit-learn tqdm
pip install pytorch-lightning
pip install torchmd-cg
```

## Usage

```
pip install moleculekit
conda install seaborn pandas jupyter
```
Check the jupyter notebook in the `tutorial` folder
